@@ -461,8 +461,8 @@ class FieldMeta(type):
         ret = cls.get_instance().__set__(*args, **kwargs)
         return ret
 
-    def __del__(cls, *args, **kwargs):
-        ret = cls.get_instance().__del__(*args, **kwargs)
+    def __delete__(cls, *args, **kwargs):
+        ret = cls.get_instance().__delete__(*args, **kwargs)
         return ret
 
 
@@ -854,6 +854,7 @@ class _Field(object):
         return self
 
     def fdel(self, orm, val):
+        orm.__dict__.pop(self.orm_interface_hash, None)
         return None
 
     def fdeleter(self, v):
